@@ -124,9 +124,24 @@ static void
 gcm_viewer_set_example_image (GcmViewerPrivate *viewer, GtkImage *image)
 {
 	gchar *filename;
-	filename = g_strdup_printf ("%s/figures/viewer-example-%02i.png", GCM_DATA, viewer->example_index);
-	gtk_image_set_from_file (image, filename);
+	gchar *path;
+	GdkPixbuf *pixbuf;
+	GError *error = NULL;
+
+	filename = g_strdup_printf ("viewer-example-%02i.png", viewer->example_index);
+	path = g_build_filename (GCM_DATA, "figures", filename, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (path, &error);
+	if (pixbuf == NULL) {
+		g_warning ("failed to load %s: %s", filename, error->message);
+		g_error_free (error);
+		goto out;
+	}
+	gtk_image_set_from_pixbuf (image, pixbuf);
+out:
 	g_free (filename);
+	g_free (path);
+	if (pixbuf != NULL)
+		g_object_unref (pixbuf);
 }
 
 /**
@@ -155,6 +170,15 @@ gcm_viewer_image_prev_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
 	gcm_viewer_set_example_image (viewer, GTK_IMAGE (viewer->preview_widget_output));
 }
 
+/**
+ * gcm_viewer_button_close_cb:
+ **/
+static void
+gcm_viewer_button_close_cb (GtkWidget *widget, GcmViewerPrivate *viewer)
+{
+	g_application_release (G_APPLICATION (viewer->application));
+}
+
 /**
  * gcm_viewer_profile_kind_to_icon_name:
  **/
@@ -800,6 +824,12 @@ struct {
 	{ CD_PROFILE_METADATA_CONNECTION_TYPE,		N_("Connection type") },
 	/* TRANSLATORS: e.g. Screen brightness in percent */
 	{ CD_PROFILE_METADATA_SCREEN_BRIGHTNESS,	N_("Screen brightness") },
+	/* TRANSLATORS: e.g. the 3D volume of the gamut graph */
+	{ "GAMUT_volume",				N_("Gamut volume") },
+	/* TRANSLATORS: e.g. what proportion of sRGB is covered */
+	{ "GAMUT_coverage(srgb)",			N_("sRGB coverage") },
+	/* TRANSLATORS: e.g. what proportion of AdobeRGB is covered */
+	{ "GAMUT_coverage(adobe-rgb)",			N_("Adobe RGB coverage") },
 	{ NULL, NULL }
 };
 
@@ -831,6 +861,7 @@ gcm_viewer_is_blacklisted_metadata_key (const gchar *key)
 				     "OSD_*",			/* OSD controls... */
 				     "vcgt",
 				     "model",
+				     "OPENICC_automatic_generated",
 				     NULL };
 	for (i = 0; blacklist[i] != NULL; i++) {
 		if (g_regex_match_simple (blacklist[i],
@@ -974,7 +1005,6 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	const gchar *profile_title;
 	gchar *temp;
 	const gchar *filename;
-	gchar *basename = NULL;
 	gchar *size_text = NULL;
 	CdProfileKind profile_kind;
 	CdColorspace profile_colorspace;
@@ -1124,11 +1154,10 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	profile_title = cd_profile_get_title (profile);
 	gtk_window_set_title (window, profile_title);
 
-	/* set basename */
+	/* set filename */
 	filename = cd_profile_get_filename (profile);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_filename"));
-	basename = g_path_get_basename (filename);
-	temp = g_markup_escape_text (basename, -1);
+	temp = g_markup_escape_text (filename, -1);
 	gtk_label_set_label (GTK_LABEL (widget), temp);
 	g_free (temp);
 
@@ -1278,7 +1307,6 @@ out:
 	if (clut_vcgt != NULL)
 		g_object_unref (clut_vcgt);
 	g_free (size_text);
-	g_free (basename);
 }
 
 /**
@@ -1629,6 +1657,9 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "button_image_prev1"));
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gcm_viewer_image_prev_cb), viewer);
+	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "button_close"));
+	g_signal_connect (widget, "clicked",
+			  G_CALLBACK (gcm_viewer_button_close_cb), viewer);
 
 	/* use named colors */
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder,
@@ -1759,15 +1790,15 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 	context = gtk_widget_get_style_context (widget);
 	gtk_style_context_add_class (context, "dim-label");
 
-	/* show main UI */
-	gtk_widget_show (main_window);
-
 	/* set the parent window if it is specified */
 	if (viewer->xid != 0) {
 		g_debug ("Setting xid %i", viewer->xid);
 		gcm_window_set_parent_xid (GTK_WINDOW (main_window), viewer->xid);
 	}
 
+	/* show main UI */
+	gtk_widget_show (main_window);
+
 	/* specified an ID */
 	if (viewer->profile_id != NULL) {
 		gcm_viewer_show_single_profile_by_id (viewer,
